@@ -2,22 +2,22 @@
 
 sphinx-apidoc is not customizeable enough to do this.
 """
+
 from __future__ import annotations
 
-import os
 import pkgutil
-from os import path
+from pathlib import Path
 
 import fava
 
 MODULES = list(pkgutil.walk_packages(fava.__path__, fava.__name__ + "."))
 
-RST_PATH = path.join(path.dirname(__file__), "api")
-if not path.isdir(RST_PATH):
-    os.mkdir(RST_PATH)
+RST_PATH = Path(__file__).parent / "api"
+if not RST_PATH.is_dir():
+    RST_PATH.mkdir()
 
 
-def heading(name, level="-"):
+def heading(name: str, level: str = "-") -> str:
     """Return the rst-heading for the given heading."""
     return f"{name}\n{level * len(name)}\n\n"
 
@@ -31,7 +31,7 @@ for package in ["fava"] + [mod.name for mod in MODULES if mod.ispkg]:
         and "_test" not in mod.name
         and mod.name.count(".") == package.count(".") + 1
     ]
-    with open(path.join(RST_PATH, f"{package}.rst"), "w") as rst:
+    with (RST_PATH / f"{package}.rst").open("w") as rst:
         rst.write(heading(package, "="))
         rst.write(f".. automodule:: {package}\n\n")
         for submod in submodules:
