@@ -1,5 +1,5 @@
 import { localStorageSyncedStore } from "../lib/store";
-import { array, constant, string, tuple, union } from "../lib/validation";
+import { array, constants, string, tuple } from "../lib/validation";
 
 const defaultValue = [
   "balance",
@@ -19,14 +19,14 @@ const defaultValue = [
 export const journalShow = localStorageSyncedStore(
   "journal-show",
   array(string),
-  () => defaultValue
+  () => defaultValue,
 );
 
 const defaultSortOrder: [string, "asc" | "desc"] = ["date", "desc"];
 
-/** The types of entries to show in the journal. */
+/** The column and order that the journal should be sorted in. */
 export const journalSortOrder = localStorageSyncedStore(
   "journal-sort-order",
-  tuple([string, union(constant("asc"), constant("desc"))]),
-  () => defaultSortOrder
+  tuple(string, constants("asc", "desc")),
+  () => defaultSortOrder,
 );
