@@ -1,6 +1,9 @@
 """Attributes for auto-completion."""
+
 from __future__ import annotations
 
+from contextlib import suppress
+from decimal import Decimal
 from typing import TYPE_CHECKING
 
 from fava.core.module_base import FavaModule
@@ -14,23 +17,21 @@ class CommoditiesModule(FavaModule):
 
     def __init__(self, ledger: FavaLedger) -> None:
         super().__init__(ledger)
-        self._names: dict[str, str] = {}
+        self.names: dict[str, str] = {}
         self.precisions: dict[str, int] = {}
 
-    def load_file(self) -> None:
-        self._names = {}
+    def load_file(self) -> None:  # noqa: D102
+        self.names = {}
         self.precisions = {}
         for commodity in self.ledger.all_entries_by_type.Commodity:
             name = commodity.meta.get("name")
             if name:
-                self._names[commodity.currency] = name
+                self.names[commodity.currency] = str(name)
             precision = commodity.meta.get("precision")
-            if precision is not None:
-                try:
+            if isinstance(precision, (str, int, Decimal)):
+                with suppress(ValueError):
                     self.precisions[commodity.currency] = int(precision)
-                except ValueError:
-                    pass
 
     def name(self, commodity: str) -> str:
-        """Get the name of a commodity (or the commodity itself if not set)"""
-        return self._names.get(commodity, commodity)
+        """Get the name of a commodity (or the commodity itself if not set)."""
+        return self.names.get(commodity, commodity)
