@@ -1,4 +1,5 @@
 """Base class for the "modules" of FavaLedger."""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
@@ -10,8 +11,8 @@ if TYPE_CHECKING:  # pragma: no cover
 class FavaModule:
     """Base class for the "modules" of FavaLedger."""
 
-    def __init__(self, ledger: FavaLedger):
+    def __init__(self, ledger: FavaLedger) -> None:
         self.ledger = ledger
 
     def load_file(self) -> None:
-        """Gets called when the file has been (re)loaded."""
+        """Run when the file has been (re)loaded."""
