@@ -1,11 +1,11 @@
-"""
-List of all available help pages.
-"""
+"""List of all available help pages."""
+
 from __future__ import annotations
 
 HELP_PAGES = {
     "_index": "Index",
     "budgets": "Budgets",
+    "conversion": "Conversion",
     "import": "Import",
     "options": "Options",
     "beancount_syntax": "Beancount Syntax",
