@@ -1,12 +1,12 @@
-# pylint: disable=missing-docstring
 from __future__ import annotations
 
 from pathlib import Path
 from textwrap import dedent
 
-from beancount.core.data import Document
 from beancount.loader import load_file
 
+from fava.beans.abc import Document
+
 
 def test_tag_discovered_plugin(tmp_path: Path) -> None:
     # Create sample files
@@ -32,9 +32,7 @@ def test_tag_discovered_plugin(tmp_path: Path) -> None:
         2016-10-31 open Assets:Cash
 
         2016-11-06 document Assets:Cash "{assets_cash_rel / non_discovered}"
-        """.replace(
-                "\\", "\\\\"
-            )
+        """.replace("\\", "\\\\")
         )
     )
 
@@ -45,7 +43,8 @@ def test_tag_discovered_plugin(tmp_path: Path) -> None:
 
     assert isinstance(entries[1], Document)
     assert discovered in entries[1].filename
-    assert entries[1].tags and "discovered" in entries[1].tags
+    assert entries[1].tags
+    assert "discovered" in entries[1].tags
 
     assert isinstance(entries[2], Document)
     assert non_discovered in entries[2].filename
